pub enum KeyCache {
Disabled,
Shared(Arc<Mutex<LruCache<PublicKey, ()>>>),
}Expand description
A cache for public keys.
This is used solely to make parsing public keys from byte slices more efficient for the very common case where a large number of identical keys are being parsed, like in the relay server.
The cache stores only successful parse results.
Variants
Disabled
The key cache is disabled.
The key cache is enabled with a fixed capacity. It is shared between multiple threads.
Implementations