ProtocolVersion

Enum ProtocolVersion 

pub enum ProtocolVersion {
    V1,
    V2,
}
The relay protocol version negotiated between client and server.

Sent as the websocket sub-protocol header Sec-Websocket-Protocol from the client. The server picks the best supported version and replies with it.

Variants are ordered by preference (highest first), so the Ord impl can be used during negotiation to pick the best version.

Variants



V1

Version 1 (the only version supported until iroh 0.98.0)



V2

Version 2 (added in iroh 0.98.0)

  • Removed Health frame (id 11)
  • Added Status frame (id 13)

Implementations

Source

impl ProtocolVersion

pub fn all() -> impl Iterator<Item = &'static str>

Returns an iterator of all supported protocol version identifiers, in order of preference.

pub fn all_joined() -> String

Returns a comma-separated string of all supported protocol version identifiers.

pub fn all_as_header_value() -> HeaderValue

Returns all supported protocol versions in a comma-seperated string as an HTTP header value.

pub fn to_str(&self) -> &'static str

Returns the protocol version identifier string.

pub fn match_from_str(s: &str) -> Option<Self>

Tries to parse a ProtocolVersion from s.

Returns None if s is not a valid protocol version string.

pub fn to_header_value(&self) -> HeaderValue

Returns this protocol version as an HTTP header value.