pub enum Mechanism {
SignedChallenge,
SignedKeyMaterial,
}Available on crate feature
server only.Expand description
The mechanism that was used for authentication.
Variants
SignedChallenge
Authentication was performed by verifying a signature of a challenge we sent
SignedKeyMaterial
Authentication was performed by verifying a signature of shared extracted TLS keying material