SuccessfulAuthentication

Struct SuccessfulAuthentication 

pub struct SuccessfulAuthentication {
    pub client_key: PublicKey,
    pub mechanism: Mechanism,
}
Available on crate feature server only.
This represents successful authentication for the client with the client_key public key via the authentication Mechanism mechanism.

You must call SuccessfulAuthentication::authorize_if to finish the protocol. Result of a successful authentication handshake.

This struct represents a client that has successfully authenticated itself to the relay server. The authorization must still be confirmed by calling Self::authorize_if to complete the protocol and notify the client of success or failure.

Fields

client_key: PublicKey

The authenticated client’s public key.

mechanism: Mechanism

The authentication mechanism that was used.

Implementations

Source

impl SuccessfulAuthentication

pub async fn authorize_if( self, is_authorized: bool, io: &mut (impl BytesStreamSink + ExportKeyingMaterial), ) -> Result<PublicKey, Error>

Completes the authorization protocol by notifying the client of success or failure.

After a client has been successfully authenticated via serverside, the server must decide whether to authorize the client (allow access) or deny it. This method sends the authorization decision to the client and completes the handshake protocol.

Arguments
  • is_authorized - Whether to grant access to the authenticated client
  • io - The WebSocket stream to send the authorization response on
Returns
  • Ok(PublicKey) - The client’s public key if authorization was granted
  • Err(Error) - If authorization was denied or communication failed