pub trait BytesStreamSink:
Stream<Item = Result<Bytes, StreamError>>
+ Sink<Bytes, Error = StreamError>
+ Unpin { }Expand description
Shorthand for a type that implements both a websocket-based stream & sink for [Bytes].
pub trait BytesStreamSink:
Stream<Item = Result<Bytes, StreamError>>
+ Sink<Bytes, Error = StreamError>
+ Unpin { }Shorthand for a type that implements both a websocket-based stream & sink for [Bytes].