pub struct RelayServiceWithNotify { /* private fields */ }Available on crate feature
server only.Expand description
Combines RelayService with a notification token.
This struct implements Service.
The notification token is triggered once the relay connection is fully established.
Implementations
Sourceimpl RelayServiceWithNotify
impl RelayServiceWithNotify
Sourcepub fn new(service: RelayService, on_establish: Arc<Notify>) -> Self
pub fn new(service: RelayService, on_establish: Arc<Notify>) -> Self
Creates a new service wrapper for a connection.
The on_establish notification is triggered once the connection is passed to the
relay protocol, i.e. after a WebSocket request on /relay is received and established.