#[non_exhaustive]pub struct RelayConfig {
pub url: RelayUrl,
pub quic: Option<RelayQuicConfig>,
pub auth_token: Option<String>,
}Expand description
Information on a specific relay server.
Includes the Url where it can be dialed.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.url: RelayUrlThe RelayUrl where this relay server can be dialed.
quic: Option<RelayQuicConfig>Configuration to speak to the QUIC endpoint on the relay server.
When None, we will not attempt to do QUIC address discovery
with this relay server.
auth_token: Option<String>Optional authorization token sent to the relay.
Set via RelayConfig::with_auth_token.
Implementations
Sourceimpl RelayConfig
impl RelayConfig
Sourcepub fn new(url: RelayUrl, quic: Option<RelayQuicConfig>) -> Self
pub fn new(url: RelayUrl, quic: Option<RelayQuicConfig>) -> Self
Creates a new relay configuration with the given URL and optional QUIC config.
Sourcepub fn with_auth_token(self, token: impl Into<String>) -> Self
pub fn with_auth_token(self, token: impl Into<String>) -> Self
Sets an authorization token for this relay.
On native targets, the token is sent as an Authorization: Bearer TOKEN
header on the WebSocket upgrade request.
When compiled to WebAssembly the token is sent as a ?token=TOKEN
query parameter on the upgrade URL, since browsers don’t allow setting
headers on WebSocket requests.