pub struct RelayMap { /* private fields */ }Expand description
List of relay server configurations to be used in an iroh endpoint.
A RelayMap can be constructed from an iterator of RelayConfig or [RelayUrl],
or by creating an empty relay map with RelayMap::empty and then adding entries with
RelayMap::insert.
Example:
let relay1 = RelayUrl::from_str("https://relay1.example.org").unwrap();
let relay2 = RelayUrl::from_str("https://relay2.example.org").unwrap();
let map = RelayMap::from_iter(vec![relay1, relay2]);Implementations
Sourceimpl RelayMap
impl RelayMap
Sourcepub fn try_from_iter<'a, T: IntoIterator<Item = &'a str>>(
urls: T,
) -> Result<Self, RelayUrlParseError>
pub fn try_from_iter<'a, T: IntoIterator<Item = &'a str>>( urls: T, ) -> Result<Self, RelayUrlParseError>
Creates a RelayMap from an iterator.
The conversion from a URL to a RelayConfig is done the same as when parsing it directly,
which means it is assumed to run QUIC on default settings as defined in RelayQuicConfig::default.
Example
let map =
RelayMap::try_from_iter(["https://relay_0.cool.com", "https://relay_1.cool.com"]).unwrap();Sourcepub fn urls<T>(&self) -> Twhere
T: FromIterator<RelayUrl>,
pub fn urls<T>(&self) -> Twhere
T: FromIterator<RelayUrl>,
Returns the URLs of all servers in this relay map.
This function is generic over the container to collect into. If you simply want a list
of URLs, call this with map.urls::<Vec<_>>() to get a Vec<RelayUrl>.
Sourcepub fn relays<T>(&self) -> T
pub fn relays<T>(&self) -> T
Returns a list with the RelayConfig for each relay in this relay map.
This function is generic over the container to collect into. If you simply want a list
of URLs, call this with map.relays::<Vec<_>>() to get a Vec<RelayConfig>.
Sourcepub fn contains(&self, url: &RelayUrl) -> bool
pub fn contains(&self, url: &RelayUrl) -> bool
Returns true if a relay with url is contained in this this relay map.
Sourcepub fn insert(
&self,
url: RelayUrl,
endpoint: Arc<RelayConfig>,
) -> Option<Arc<RelayConfig>>
pub fn insert( &self, url: RelayUrl, endpoint: Arc<RelayConfig>, ) -> Option<Arc<RelayConfig>>
Inserts a new relay into the relay map.
Sourcepub fn remove(&self, url: &RelayUrl) -> Option<Arc<RelayConfig>>
pub fn remove(&self, url: &RelayUrl) -> Option<Arc<RelayConfig>>
Removes an existing relay by its URL.
Sourcepub fn with_auth_token(self, auth_token: impl Into<String>) -> Self
pub fn with_auth_token(self, auth_token: impl Into<String>) -> Self
Sets an authorization token for all relays configured in this relay map.
This applies RelayConfig::with_auth_token to all current entries in this relay map.
Any entries added to this relay map after calling this will not have the token set.
See RelayConfig::with_auth_token for details.