CaRootsConfig

Struct CaRootsConfig 

pub struct CaRootsConfig { /* private fields */ }
Configures the trusted CA root certificates for non-iroh TLS connections.

These roots are used whenever iroh establishes standard TLS connections to external services, such as iroh relays, pkarr servers, or DNS-over-HTTPS resolvers.

The configured Certificate Authority (CA) roots are only used for verifying the validity of TLS certificates presented by those external services. These CAs don’t need to be trusted for the integrity or authenticity of native iroh connections, which rely on iroh’s own cryptographic authentication mechanisms.

Implementations

Source

impl CaRootsConfig

pub fn system() -> Self

Available on crate feature platform-verifier only.

Use the operating system’s certificate facilities for verifying the validity of TLS certificates.

See [rustls_platform_verifier] for details how trust anchors are retrieved on different platforms.

Note: Additional certificates added via Self::with_extra_roots will be ignored on Android due to missing support in [rustls].

pub fn embedded() -> Self

Use a compiled-in copy of the root certificates trusted by Mozilla.

See [webpki_roots] for details.

pub fn insecure_skip_verify() -> Self

Available on crate features test-utils only.

INSECURE: Do not verify server certificates at all.

May only be used in tests or local development setups.

pub fn custom(roots: impl IntoIterator<Item = CertificateDer<'static>>) -> Self

Only trust the explicitly set root certificates.

pub fn with_extra_roots( self, extra_roots: impl IntoIterator<Item = CertificateDer<'static>>, ) -> Self

Add additional root certificates to the list of trusted certificates.

pub fn server_cert_verifier( &self, crypto_provider: Arc<CryptoProvider>, ) -> Result<Arc<dyn ServerCertVerifier>>

Builds a [ServerCertVerifier] from this config.

pub fn client_config( &self, crypto_provider: Arc<CryptoProvider>, ) -> Result<ClientConfig>

Build a [ClientConfig] from this config.