pub struct SuccessfulAuthentication {
pub client_key: PublicKey,
pub mechanism: Mechanism,
}server only.Expand description
This represents successful authentication for the client with the client_key public key
via the authentication Mechanism mechanism.
You must call SuccessfulAuthentication::authorize_if to finish the protocol.
Result of a successful authentication handshake.
This struct represents a client that has successfully authenticated itself to the relay
server. The authorization must still be confirmed by calling Self::authorize_if to
complete the protocol and notify the client of success or failure.
Fields
client_key: PublicKeyThe authenticated client’s public key.
mechanism: MechanismThe authentication mechanism that was used.
Implementations
Sourceimpl SuccessfulAuthentication
impl SuccessfulAuthentication
Completes the authorization protocol by notifying the client of success or failure.
After a client has been successfully authenticated via serverside, the server must
decide whether to authorize the client (allow access) or deny it. This method sends
the authorization decision to the client and completes the handshake protocol.
Arguments
is_authorized- Whether to grant access to the authenticated clientio- The WebSocket stream to send the authorization response on
Returns
Ok(PublicKey)- The client’s public key if authorization was grantedErr(Error)- If authorization was denied or communication failed